@@ -213,7 +213,12 @@ class Headmouse(metaclass=HeadmouseSingleton):
         self.nose_x = nose_position[:, 0]
         self.nose_y = nose_position[:, 1]
 
-    def show_image(self):
+    def show_image(self, show_thresh=True):
+        if show_thresh:
+            start = (int(self.center[0] - self.thresh_x/2), int(self.center[1] - self.thresh_y/2))
+            end = (int(self.center[0] + self.thresh_x/2), int(self.center[1] + self.thresh_y/2))
+            cv2.circle(self.frame, (self.nose_x, self.nose_y), 3, (255,0,0), 1)
+            cv2.rectangle(self.frame, start, end, (255,0,0), 1)
         cv2.imshow('My window', self.frame)
 
     def destroy_window(self):
